import { useMemo } from "react"
import {
  line,
  curveNatural,
  geoPath,
  geoNaturalEarth1,
  geoGraticule,
} from 'd3';

const projection = geoNaturalEarth1();
const path = geoPath(projection);
const graticule = geoGraticule();

// Country has the borders between countries
// Interiors has only interior borders, so no sea borders
export const Marks = ({
  worldAtlas: { land, interiors },
  cities,
  sizeScale,
  sizeValue,
}) => (
  <g className="marks">
    // Use Memo on JSX. 
    // 1. escape into js {}
    // 2. call useMemo
    // 3. to return multiple jsx top level elements, use react fragment <></>
    {useMemo(
      () => (
        <>
          <path
            className="sphere"
            d={path({ type: 'Sphere' })}
          />
          <path
            className="graticule"
            d={path(graticule())}
          />
          {land.features.map((feature) => (
            <path className="land" d={path(feature)} />
          ))}
          <path className="interiors" d={path(interiors)} />
        </>
      ),
      [path, graticule, land, interiors]
    )}
    // Plot cities
    {cities.map((d) => {
      const [x, y] = projection(d.coords);
      return (
        <circle cx={x} cy={y} r={sizeScale(sizeValue(d))} />
      );
    })}
  </g>
);
