import React, { useState } from 'react';
import ReactDOM from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { useData } from './useData';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';

const width = 960;
const height = 500;
const dateHistogramSize = 0.2; // 20% at the bottom

const xValue = (d) => d['Reported Date']; // could in theory put other dataset stuff here and give to DateHistogram as props

const App = () => {
  const worldAtlas = useWorldAtlas();
  const data = useData();
  const [brushExtent, setBrushExtent] = useState(); // 3x undefined at start, because we'reloading data twice

  if (!worldAtlas || !data) {
    return <pre>Loading...</pre>;
  }

  // Return true if data is between the selected dates
  // Use guard if brushExtent is not defined, just return data
  const filteredData = brushExtent ? data.filter((d) => {
    const date = xValue(d);
    return date > brushExtent[0] && date < brushExtent[1];
  }) : data;

  return (
    <svg width={width} height={height}>
      // First View
      <BubbleMap data={data} filteredData={filteredData} worldAtlas={worldAtlas} />
      // Second View
      <g
        transform={`translate(0, ${
          height - dateHistogramSize * height
        })`}
      >
        <DateHistogram
          data={data}
          height={dateHistogramSize * height}
          width={width}
          setBrushExtent={setBrushExtent}
          xValue={xValue}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
